| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Data.TI85.File
Contents
Description
A collection of types and utilities for dealing with TI Link backup files.
Synopsis
- module Data.TI85.File.Variable
- module Data.TI85.File.Backup
- data TIHeader = TIHeader {}
- data TIFileData
- data TIFile = TIFile {
- tiHeader :: TIHeader
- tiData :: TIFileData
- tiChecksum :: Word16
Re-exported modules
module Data.TI85.File.Variable
module Data.TI85.File.Backup
Types
The TI-85 header is common between backup files and variable files.
| 8 Byte | 3 | 42 Byte |
|---|---|---|
| **TI85** | xyz | Comment |
where xyz is always 0x1a,0x0c,0x00.
Constructors
| TIHeader | |
Fields
| |
data TIFileData Source #
There are two possible file formats
- Variable files contain one or more variables, encoded in a variable-specific way.
- Backup files contain memory dumps, which also include variable data in a raw form.
Constructors
| BackupData TIBackupData | |
| VariableData TIVarData |
Instances
| Show TIFileData Source # | |
Defined in Data.TI85.File Methods showsPrec :: Int -> TIFileData -> ShowS # show :: TIFileData -> String # showList :: [TIFileData] -> ShowS # | |
All TI Link files have a common header and
checksum, with a data section that differs
between backup and variable types.
See TIFileData.
Constructors
| TIFile | |
Fields
| |